[jboss-cvs] JBossAS SVN: r81834 - in trunk/varia/src/main/org/jboss/services/binding: impl and 1 other directory.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Sun Nov 30 14:41:49 EST 2008


Author: bstansberry at jboss.com
Date: 2008-11-30 14:41:48 -0500 (Sun, 30 Nov 2008)
New Revision: 81834

Modified:
   trunk/varia/src/main/org/jboss/services/binding/ManagedServiceBinding.java
   trunk/varia/src/main/org/jboss/services/binding/ServiceBinding.java
   trunk/varia/src/main/org/jboss/services/binding/impl/ServiceBindingSet.java
Log:
[JBAS-6259] Add some @ManagementProperty descriptions

Modified: trunk/varia/src/main/org/jboss/services/binding/ManagedServiceBinding.java
===================================================================
--- trunk/varia/src/main/org/jboss/services/binding/ManagedServiceBinding.java	2008-11-30 16:55:25 UTC (rev 81833)
+++ trunk/varia/src/main/org/jboss/services/binding/ManagedServiceBinding.java	2008-11-30 19:41:48 UTC (rev 81834)
@@ -35,7 +35,7 @@
  * management tools can use.
  * @author Brian Stansberry
  */
- at ManagementObject(componentType=@ManagementComponent(type="MCBean", subtype="ServiceBinding"),
+ at ManagementObject(componentType=@ManagementComponent(type="MCBean", subtype="ManagedServiceBinding"),
       properties=ManagementProperties.EXPLICIT)
 public class ManagedServiceBinding extends ServiceBinding
 {
@@ -98,18 +98,19 @@
    // ------------------------------------------------------------  Properties
 
    @Override
-   @ManagementProperty(use={ViewUse.CONFIGURATION}) // overrides superclass annotation's use attribute
+   @ManagementProperty(description="the host name or " +
+         "string notation IP address to use for the binding",
+         use={ViewUse.CONFIGURATION}) // overrides superclass annotation's use attribute
    public String getHostName()
    {
-      // TODO Auto-generated method stub
       return super.getHostName();
    }
 
    @Override
-   @ManagementProperty(use={ViewUse.CONFIGURATION}) // overrides superclass annotation's use attribute
+   @ManagementProperty(description="the port to use for the binding",
+         use={ViewUse.CONFIGURATION}) // overrides superclass annotation's use attribute
    public int getPort()
    {
-      // TODO Auto-generated method stub
       return super.getPort();
    }
 

Modified: trunk/varia/src/main/org/jboss/services/binding/ServiceBinding.java
===================================================================
--- trunk/varia/src/main/org/jboss/services/binding/impl/ServiceBindingSet.java	2008-11-30 16:55:25 UTC (rev 81833)
+++ trunk/varia/src/main/org/jboss/services/binding/impl/ServiceBindingSet.java	2008-11-30 19:41:48 UTC (rev 81834)
@@ -114,14 +114,15 @@
 
    // -------------------------------------------------------------- Properties
    
-   @ManagementProperty
+   @ManagementProperty(description="the name of the set")
    @ManagementObjectID(type="ServiceBindingSet")
    public String getName()
    {
       return bindingSetName;
    }
 
-   @ManagementProperty
+   @ManagementProperty(description="the host name bindings associated with this " +
+   		"set should use not configured in the binding itself")
    public String getDefaultHostName()
    {
       return defaultHostName;
@@ -132,7 +133,8 @@
       this.defaultHostName = defaultHostName;
    }
 
-   @ManagementProperty
+   @ManagementProperty(description="offset that should be applied to non-fixed-port" +
+   		"bindings associated with this set")
    public int getPortOffset()
    {
       return portOffset;
@@ -143,7 +145,8 @@
       this.portOffset = portOffset;
    }
    
-   @ManagementProperty
+   @ManagementProperty(description="bindings that either override or are additions " +
+   		"to the base bindings configured in the ServiceBindingStore")
    public Set<ManagedServiceBinding> getOverrideBindings()
    {
       @SuppressWarnings("unchecked")      




More information about the jboss-cvs-commits mailing list
--- trunk/varia/src/main/org/jboss/services/binding/ServiceBinding.java	2008-11-30 16:55:25 UTC (rev 81833)
+++ trunk/varia/src/main/org/jboss/services/binding/ServiceBinding.java	2008-11-30 19:41:48 UTC (rev 81834)
@@ -199,20 +199,21 @@
     * 
     * @return the name. Will not be <code>null</code>.
     */
-   @ManagementProperty
+   @ManagementProperty(description="the name of the service to which this binding applies")
    public String getServiceName()
    {
       return serviceName;
    }
 
    /**
     * Gets a qualifier identifying which particularly binding within 
     * {@link #getServiceName() the service} this is.
     *
     * @return the name, or <code>null</code> if this is an unnamed default binding
     *         for the service.
     */
-   @ManagementProperty
+   @ManagementProperty(description="a qualifier identifying which particular " +
+   		                           "binding within the service this is")
    public String getBindingName()
    {
       return this.bindingName;
@@ -224,7 +225,7 @@
     * @return the {@link #getServiceName() serviceName}:{@link #getBindingName() bindingName} or
     *         just the service name if the binding name is <code>null</code>.
     */
-   @ManagementProperty
+   @ManagementProperty(description="the fully qualified binding name")
    @ManagementObjectID(type="ServiceBinding")
    public String getFullyQualifiedName()
    {
@@ -236,7 +237,8 @@
     *
     * @return the hostname or address
     */
-   @ManagementProperty(use={ViewUse.STATISTIC})
+   @ManagementProperty(use={ViewUse.STATISTIC}, description="the host name or " +
+   		"string notation IP address to use for the binding")
    public String getHostName()
    {
       return this.hostName;
@@ -247,7 +249,7 @@
     *
     * @return The port
     */
-   @ManagementProperty(use={ViewUse.STATISTIC})
+   @ManagementProperty(use={ViewUse.STATISTIC}, description="the port to use for the binding")
    public int getPort()
    {
       return this.port;
@@ -258,7 +260,8 @@
     *
     * @return  The binding address
     */
-   @ManagementProperty(use={ViewUse.STATISTIC})
+   @ManagementProperty(use={ViewUse.STATISTIC}, description="the InetAddress of " +
+   		"the interface to use for the binding")
    public InetAddress getBindAddress()
    {
       return this.bindAddress;
@@ -199,20 +199,21 @@
 
    /**
-    * Gets a qualifier identifying which particularly binding within 
+    * Gets a qualifier identifying which particular binding within 
     * {@link #getServiceName() the service} this is.
     *

Modified: trunk/varia/src/main/org/jboss/services/binding/impl/ServiceBindingSet.java
===================================================================